@@ -2,9 +2,6 @@
 """
 Datalink classes and mixins
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 import numpy as np
 
 from .query import DALResults, DALQuery, DALService, Record
@@ -20,7 +17,6 @@ from astropy.io.votable.tree import Resource, Group
 from astropy.utils.collections import HomogeneousList
 
 from ..utils.decorators import stream_decode_content
-from ..utils.http import session as s
 
 
 # monkeypatch astropy with group support in RESOURCE
@@ -88,12 +84,12 @@ def _get_accessurl_from_params(params):
     return params["accessURL"].value
 
 
-class AdhocServiceResultsMixin(object):
+class AdhocServiceResultsMixin:
     """
     Mixing for adhoc:service functionallity for results classes.
     """
-    def __init__(self, votable, url=None):
-        super(AdhocServiceResultsMixin, self).__init__(votable, url=url)
+    def __init__(self, votable, url=None, session=None):
+        super().__init__(votable, url=url, session=session)
 
         self._adhocservices = list(
             resource for resource in votable.resources
@@ -101,8 +97,7 @@ class AdhocServiceResultsMixin(object):
         )
 
     def iter_adhocservices(self):
-        for adhocservice in self._adhocservices:
-            yield adhocservice
+        yield from self._adhocservices
 
     def get_adhocservice_by_ivoid(self, ivo_id):
         """
@@ -162,7 +157,7 @@ class DatalinkResultsMixin(AdhocServiceResultsMixin):
             yield record.getdatalink()
 
 
-class DatalinkRecordMixin(object):
+class DatalinkRecordMixin:
     """
     Mixin for record classes, providing functionallity for datalink.
 
@@ -182,12 +177,12 @@ class DatalinkRecordMixin(object):
     def getdataset(self, timeout=None):
         try:
             url = next(self.getdatalink().bysemantics('#this')).access_url
-            r = s.get(url, stream=True, timeout=timeout)
-            r.raise_for_status()
-            return r.raw
+            response = self._session.get(url, stream=True, timeout=timeout)
+            response.raise_for_status()
+            return response.raw
         except (DALServiceError, ValueError, StopIteration):
             # this should go to Record.getdataset()
-            return super(DatalinkRecordMixin, self).getdataset(timeout=timeout)
+            return super().getdataset(timeout=timeout)
 
 
 class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
@@ -195,7 +190,7 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
     a representation of a Datalink service
     """
 
-    def __init__(self, baseurl):
+    def __init__(self, baseurl, session=None):
         """
         instantiate a Datalink service
 
@@ -203,8 +198,17 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
         ----------
         baseurl :  str
            the base URL that should be used for forming queries to the service.
+        session : object
+           optional session to use for network requests
         """
-        super(DatalinkService, self).__init__(baseurl)
+        super().__init__(baseurl, session=session)
+
+        # Check if the session has an update_from_capabilities attribute.
+        # This means that the session is aware of IVOA capabilities,
+        # and can use this information in processing network requests.
+        # One such usecase for this is auth.
+        if hasattr(self._session, 'update_from_capabilities'):
+            self._session.update_from_capabilities(self.capabilities)
 
     def run_sync(self, id, responseformat=None, **keywords):
         """
@@ -252,7 +256,7 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
 
 class DatalinkQuery(DALQuery):
     """
-    a class for preparing an query to an Datalink service.  Query constraints
+    A class for preparing a query to a Datalink service.  Query constraints
     are added via its service type-specific methods.  The various execute()
     functions will submit the query and return the results.
 
@@ -262,6 +266,9 @@ class DatalinkQuery(DALQuery):
     :py:attr:`~pyvo.dal.query.DALQuery.baseurl` to send a configured
     query to another service.
 
+    A session can also optionally be passed in that will be used for
+    network transactions made by this object to remote services.
+
     In addition to the search constraint attributes described below, search
     parameters can be set generically by name via dict semantics.
     The typical function for submitting the query is ``execute()``; however,
@@ -269,22 +276,25 @@ class DatalinkQuery(DALQuery):
     allowing the caller to take greater control of the result processing.
     """
     @classmethod
-    def from_resource(cls, row, resource, **kwargs):
+    def from_resource(cls, row, resource, session=None, **kwargs):
         """
         Creates a instance from a Record and a Datalink Resource.
 
         XML Hierarchy:
 
-        <FIELD id="ID"...>
-        <FIELD id="srcGroup">
+        .. code:: xml
 
-        <GROUP name="inputParams">
-            <PARAM name="ID" datatype="char" arraysize="*" value=""
-                ref="primaryID"/>
-            <PARAM name="CALIB" datatype="char" arraysize="*" value="FLUX"/>
-            <PARAM name="GROUP" datatype="char" arraysize="*" value=""
-                ref="srcGroup"/>
-        </GROUP>
+            <FIELD id="ID">
+            <FIELD id="srcGroup">
+
+            <GROUP name="inputParams">
+                <PARAM name="ID" datatype="char" arraysize="*" value=""
+                    ref="primaryID"/>
+                <PARAM name="CALIB" datatype="char" arraysize="*"
+                    value="FLUX"/>
+                <PARAM name="GROUP" datatype="char" arraysize="*" value=""
+                    ref="srcGroup"/>
+            </GROUP>
         """
         input_params = _get_input_params_from_resource(resource)
         # get params outside of any group
@@ -314,10 +324,10 @@ class DatalinkQuery(DALQuery):
             except KeyError:
                 query_params[name] = query_param
 
-        return cls(accessurl, **query_params)
+        return cls(accessurl, session=session, **query_params)
 
     def __init__(
-            self, baseurl, id=None, responseformat=None, **keywords):
+            self, baseurl, id=None, responseformat=None, session=None, **keywords):
         """
         initialize the query object with the given parameters
 
@@ -329,8 +339,10 @@ class DatalinkQuery(DALQuery):
             the dataset identifier
         responseformat : str
             the output format
+        session : object
+            optional session to use for network requests
         """
-        super(DatalinkQuery, self).__init__(baseurl, **keywords)
+        super().__init__(baseurl, session=session, **keywords)
 
         if id:
             self["ID"] = id
@@ -351,7 +363,7 @@ class DatalinkQuery(DALQuery):
         DALFormatError
            for errors parsing the VOTable response
         """
-        return DatalinkResults(self.execute_votable(), url=self.queryurl)
+        return DatalinkResults(self.execute_votable(), url=self.queryurl, session=self._session)
 
 
 class DatalinkResults(DatalinkResultsMixin, DALResults):
@@ -425,7 +437,7 @@ class DatalinkResults(DatalinkResultsMixin, DALResults):
         --------
         Record
         """
-        return DatalinkRecord(self, index)
+        return DatalinkRecord(self, index, session=self._session)
 
     def bysemantics(self, semantics):
         """
@@ -472,7 +484,7 @@ class DatalinkResults(DatalinkResultsMixin, DALResults):
         raise IndexError("No processing service found in datalink result")
 
 
-class SodaRecordMixin(object):
+class SodaRecordMixin:
     """
     Mixin for soda functionallity for record classes.
     If used, it's result class must have
@@ -667,7 +679,7 @@ class SodaQuery(DatalinkQuery):
     def __init__(
             self, baseurl, circle=None, range=None, polygon=None, band=None,
             **kwargs):
-        super(SodaQuery, self).__init__(baseurl, **kwargs)
+        super().__init__(baseurl, **kwargs)
 
         if circle:
             self.circle = circle
