@@ -6,11 +6,9 @@ A module for parsing and working with mimetypes
 import mimetypes
 import mimeparse
 
-import six
-
 from astropy.io.fits import HDUList
 
-from ..utils.http import session as s
+from ..utils.http import use_session
 
 
 mimetypes.add_type('application/fits', 'fits')
@@ -51,14 +49,14 @@ def mime2extension(mimetype, default=None):
     if not mimetype:
         return default
 
-    if type(mimetype) == six.text_type:
+    if type(mimetype) == str:
         mimetype = mimetype.encode('utf-8')
 
     ext = mimetypes.guess_extension(mimetype, strict=False)
     return ext
 
 
-def mime_object_maker(url, mimetype):
+def mime_object_maker(url, mimetype, session=None):
     """
     return a data object suitable for the mimetype given.
     this will either return a astropy fits object or a pyvo DALResults object,
@@ -70,26 +68,29 @@ def mime_object_maker(url, mimetype):
         the object download url
     mimetype : str
         the content mimetype
+    session : object
+        optional session to use for network requests
     """
+    session = use_session(session)
     mimetype = mimeparse.parse_mime_type(mimetype)
 
     if mimetype[0] == 'text':
-        return s.get(url).text
+        return session.get(url).text
 
     if mimetype[1] == 'fits' or mimetype[1] == 'x-fits':
-        r = s.get(url)
-        return HDUList.fromstring(r.content)
+        response = session.get(url)
+        return HDUList.fromstring(response.content)
 
     if mimetype[0] == 'image':
         from PIL import Image
         from io import BytesIO
-        r = s.get(url)
-        b = BytesIO(r.content)
-        return Image.open(b)
+        response = session.get(url)
+        bio = BytesIO(response.content)
+        return Image.open(bio)
 
     if mimetype[1] == 'x-votable' or mimetype[1] == 'x-votable+xml':
         # As soon as there are some kind of recursive data structures,
-        # things start to get really f*cked up
+        # things start to get messy
         if mimetype[2].get('content', None) == 'datalink':
             from .adhoc import DatalinkResults
             return DatalinkResults.from_result_url(url)
