@@ -20,9 +20,6 @@ other externally defined table.  In this case there is no VO defined
 standard data model.  Usually the field names are used to uniquely
 identify table columns.
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 __all__ = ["DALService", "DALQuery", "DALResults", "Record"]
 
 import os
@@ -37,7 +34,6 @@ import collections
 
 from warnings import warn
 
-import six
 from astropy.table.table import Table
 from astropy.io.votable import parse as votableparse
 from astropy.io.votable.ucd import parse_ucd
@@ -49,16 +45,16 @@ from .exceptions import (DALFormatError, DALServiceError, DALQueryError)
 from .. import samp
 
 from ..utils.decorators import stream_decode_content
-from ..utils.http import session as s
+from ..utils.http import use_session
 
 
-class DALService(object):
+class DALService:
     """
     an abstract base class representing a DAL service located a particular
     endpoint.
     """
 
-    def __init__(self, baseurl):
+    def __init__(self, baseurl, session=None):
         """
         instantiate the service connecting it to a base URL
 
@@ -66,8 +62,11 @@ class DALService(object):
         ----------
         baseurl :  str
            the base URL that should be used for forming queries to the service.
+        session : object
+           optional session to use for network requests
         """
         self._baseurl = baseurl
+        self._session = use_session(session)
 
     @property
     def baseurl(self):
@@ -109,7 +108,7 @@ class DALService(object):
         DALQuery
            a generic query object
         """
-        q = DALQuery(self.baseurl, **keywords)
+        q = DALQuery(self.baseurl, session=self._session, **keywords)
         return q
 
     def describe(self):
@@ -123,18 +122,22 @@ class DALQuery(dict):
     functions will submit the query and return the results.
 
     The base URL for the query can be changed via the baseurl property.
+
+    A session can also optionally be passed in that will be used for
+    network transactions made by this object to remote services.
     """
 
     _ex = None
 
-    def __init__(self, baseurl, **keywords):
+    def __init__(self, baseurl, session=None, **keywords):
         """
         initialize the query object with a baseurl
         """
-        if type(baseurl) == six.binary_type:
+        if type(baseurl) == bytes:
             baseurl = baseurl.decode("utf-8")
 
         self._baseurl = baseurl.rstrip("?")
+        self._session = use_session(session)
 
         self.update({key.upper(): value for key, value in keywords.items()})
 
@@ -160,7 +163,7 @@ class DALQuery(dict):
         DALFormatError
            for errors parsing the VOTable response
         """
-        return DALResults(self.execute_votable(), self.queryurl)
+        return DALResults(self.execute_votable(), self.queryurl, session=self._session)
 
     def execute_raw(self):
         """
@@ -185,15 +188,15 @@ class DALQuery(dict):
         No exceptions are raised here because non-2xx responses might still
         contain payload. They can be raised later by calling ``raise_if_error``
         """
-        r = self.submit()
+        response = self.submit()
 
         try:
-            r.raise_for_status()
+            response.raise_for_status()
         except requests.RequestException as ex:
             # save for later use
             self._ex = ex
         finally:
-            return r.raw
+            return response.raw
 
     def submit(self):
         """
@@ -202,8 +205,8 @@ class DALQuery(dict):
         url = self.queryurl
         params = {k: v for k, v in self.items()}
 
-        r = s.get(url, params=params, stream=True)
-        return r
+        response = self._session.get(url, params=params, stream=True)
+        return response
 
     def execute_votable(self):
         """
@@ -253,7 +256,7 @@ class DALQuery(dict):
         return self.baseurl
 
 
-class DALResults(object):
+class DALResults:
     """
     Results from a DAL query.  It provides random access to records in
     the response.  Alternatively, it can provide results via a Cursor
@@ -261,19 +264,23 @@ class DALResults(object):
     """
     @classmethod
     @stream_decode_content
-    def _from_result_url(cls, result_url):
-        return s.get(result_url, stream=True).raw
+    def _from_result_url(cls, result_url, session):
+        return session.get(result_url, stream=True).raw
 
     @classmethod
-    def from_result_url(cls, result_url):
+    def from_result_url(cls, result_url, session=None):
         """
         Create a result object from a url.
-        """
-        return cls(
-            votableparse(cls._from_result_url(result_url).read),
-            url=result_url)
 
-    def __init__(self, votable, url=None):
+        Uses the optional session to make the request.
+        """
+        session = use_session(session)
+        return cls(
+            votableparse(cls._from_result_url(result_url, session).read),
+            url=result_url,
+            session=session)
+
+    def __init__(self, votable, url=None, session=None):
         """
         initialize the cursor.  This constructor is not typically called
         by directly applications; rather an instance is obtained from calling
@@ -286,6 +293,8 @@ class DALResults(object):
            astropy.io.votable.tree.VOTableFile instance.
         url : str
            the URL that produced the response
+        session : object
+           optional session to use for network requests
 
         Raises
         ------
@@ -299,6 +308,8 @@ class DALResults(object):
         self._votable = votable
 
         self._url = url
+        self._session = use_session(session)
+
         self._status = self._findstatus(votable)
         if self._status[0].lower() not in ("ok", "overflow"):
             raise DALQueryError(self._status[1], self._status[0], url)
@@ -529,7 +540,7 @@ class DALResults(object):
         --------
         Record
         """
-        return Record(self, index)
+        return Record(self, index, session=self._session)
 
     def getvalue(self, name, index):
         """
@@ -615,9 +626,10 @@ class Record(Mapping):
     additional functions for access to service type-specific data.
     """
 
-    def __init__(self, results, index):
+    def __init__(self, results, index, session=None):
         self._results = results
         self._index = index
+        self._session = use_session(session)
         self._mapping = collections.OrderedDict(
             zip(
                 results.fieldnames,
@@ -650,7 +662,7 @@ class Record(Mapping):
         """
         out = self._mapping.get(key, default)
 
-        if decode and isinstance(out, six.binary_type):
+        if decode and isinstance(out, bytes):
             out = out.decode('ascii')
 
         return out
@@ -693,7 +705,7 @@ class Record(Mapping):
                     "meta.ref.url" in field.ucd
             ):
                 out = self[fieldname]
-                if isinstance(out, six.binary_type):
+                if isinstance(out, bytes):
                     out = out.decode('utf-8')
                 return out
         return None
@@ -742,12 +754,12 @@ class Record(Mapping):
             raise KeyError("no dataset access URL recognized in record")
 
         if timeout:
-            r = s.get(url, stream=True, timeout=timeout)
+            response = self._session.get(url, stream=True, timeout=timeout)
         else:
-            r = s.get(url, stream=True)
+            response = self._session.get(url, stream=True)
 
-        r.raise_for_status()
-        return r.raw
+        response.raise_for_status()
+        return response.raw
 
     def cachedataset(self, filename=None, dir=".", timeout=None, bufsize=None):
         """
@@ -832,7 +844,7 @@ class Record(Mapping):
         if not os.path.exists(dir):
             os.mkdir(dir)
         if not os.path.isdir(dir):
-            raise ValueError("{0}: not a directory".format(dir))
+            raise ValueError("{}: not a directory".format(dir))
 
         if not base:
             base = self.suggest_dataset_basename()
@@ -844,7 +856,7 @@ class Record(Mapping):
         n = self._dsname_no
 
         def mkpath(i):
-            return os.path.join(dir, "{0}-{1}.{2}".format(base, i, ext))
+            return os.path.join(dir, "{}-{}.{}".format(base, i, ext))
 
         if n > 0:
             # find the last file written of the form, base-n.ext
@@ -854,7 +866,7 @@ class Record(Mapping):
             n += 1
         if n == 0:
             # never wrote a file of form, base-n.ext; try base.ext
-            path = os.path.join(dir, "{0}.{1}".format(base, ext))
+            path = os.path.join(dir, "{}.{}".format(base, ext))
             if not os.path.exists(path):
                 return path
             n += 1
@@ -888,7 +900,7 @@ class Record(Mapping):
         return default
 
 
-class Iter(object):
+class Iter:
     def __init__(self, res):
         self.resultset = res
         self.pos = 0
@@ -907,7 +919,7 @@ class Iter(object):
     next = __next__
 
 
-class Upload(object):
+class Upload:
     """
     This class represents a DALI Upload as described in
     http://www.ivoa.net/documents/DALI/20161101/PR-DALI-1.1-20161101.html#tth_sEc3.4.5
@@ -1007,7 +1019,7 @@ class Upload(object):
             self._content.raise_if_error()
             uri = self._content.result_uri
         else:
-            uri = six.text_type(self._content)
+            uri = str(self._content)
 
         return uri
 
@@ -1044,11 +1056,6 @@ class UploadList(list):
         return ";".join(upload.query_part() for upload in self)
 
 
-if six.PY3:
-    _image_mt_re = re.compile(b'^image/(\w+)')
-    _text_mt_re = re.compile(b'^text/(\w+)')
-    _votable_mt_re = re.compile(b'^(\w+)/(x-)?votable(\+\w+)?')
-else:
-    _image_mt_re = re.compile(r'^image/(\w+)')
-    _text_mt_re = re.compile(r'^text/(\w+)')
-    _votable_mt_re = re.compile(r'^(\w+)/(x-)?votable(\+\w+)?')
+_image_mt_re = re.compile(r'^image/(\w+)')
+_text_mt_re = re.compile(r'^text/(\w+)')
+_votable_mt_re = re.compile(r'^(\w+)/(x-)?votable(\+\w+)?')
