@@ -2,9 +2,6 @@
 """
 A module for accessing remote source and observation catalogs
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 from functools import partial
 from datetime import datetime
 from time import sleep
@@ -12,7 +9,6 @@ from distutils.version import LooseVersion
 
 import requests
 
-import six
 from astropy.io.votable import parse as votableparse
 
 from .query import (
@@ -25,11 +21,29 @@ from ..io import vosi, uws
 from ..io.vosi import tapregext as tr
 
 from ..utils.formatting import para_format_desc
-from ..utils.http import session as s
+from ..utils.http import use_session
 
 __all__ = [
     "search", "escape", "TAPService", "TAPQuery", "AsyncTAPJob", "TAPResults"]
 
+IVOA_DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"
+
+
+def _from_ivoa_format(datetime_str):
+    """
+    parses an ivoa date in ISO 8601 format: YYYY-MM-DDTHH:MM:SS.[mmm]Z
+
+    :param datetime_str:
+    :return: corresponding datetime object
+    """
+    # TODO Replace with datetime.fromisoformat(date_string) in Python3.7+
+    try:
+        # with fraction of seconds first
+        return datetime.strptime(datetime_str, IVOA_DATETIME_FORMAT)
+    except ValueError:
+        # and without
+        return datetime.strptime(datetime_str, "%Y-%m-%dT%H:%M:%SZ")
+
 
 def escape(term):
     """
@@ -81,7 +95,7 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
 
     _tables = None
 
-    def __init__(self, baseurl):
+    def __init__(self, baseurl, session=None):
         """
         instantiate a Tablee Access Protocol service
 
@@ -89,8 +103,17 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
         ----------
         baseurl :  str
            the base URL that should be used for forming queries to the service.
+        session : object
+           optional session to use for network requests
         """
-        super(TAPService, self).__init__(baseurl)
+        super().__init__(baseurl, session=session)
+
+        # Check if the session has an update_from_capabilities attribute.
+        # This means that the session is aware of IVOA capabilities,
+        # and can use this information in processing network requests.
+        # One such usecase for this is auth.
+        if hasattr(self._session, 'update_from_capabilities'):
+            self._session.update_from_capabilities(self.capabilities)
 
     @property
     def tables(self):
@@ -98,9 +121,9 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
         returns tables as a dict-like object
         """
         if self._tables is None:
-            tables_url = '{0}/tables'.format(self.baseurl)
+            tables_url = '{}/tables'.format(self.baseurl)
 
-            response = s.get(tables_url, stream=True)
+            response = self._session.get(tables_url, stream=True)
 
             try:
                 response.raise_for_status()
@@ -234,7 +257,7 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
         AsyncTAPJob
         """
         job = AsyncTAPJob.create(
-            self.baseurl, query, language, maxrec, uploads, **keywords)
+            self.baseurl, query, language, maxrec, uploads, self._session, **keywords)
         job = job.run().wait()
         job.raise_if_error()
         result = job.fetch_result()
@@ -271,7 +294,7 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
         AsyncTAPJob
         """
         return AsyncTAPJob.create(
-            self.baseurl, query, language, maxrec, uploads, **keywords)
+            self.baseurl, query, language, maxrec, uploads, self._session, **keywords)
 
     def create_query(
             self, query=None, mode="sync", language="ADQL", maxrec=None,
@@ -299,7 +322,76 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
             a mapping from table names to objects containing a votable.
         """
         return TAPQuery(
-            self.baseurl, query, mode, language, maxrec, uploads, **keywords)
+            self.baseurl, query, mode, language, maxrec, uploads, self._session, **keywords)
+
+    def get_job(self, job_id):
+        """
+        Returns the job corresponding to an ID. Note that the caller must be
+        able to see the job in the current security context.
+
+        Parameters
+        ----------
+        job_id : str
+            ID of the job to view
+
+        Returns
+        -------
+        `~pyvo.io.vosi.endpoint.JobSummary` corresponding to the job ID
+        """
+        response = self._session.get(
+            self.baseurl + '/async/' + job_id,
+            stream=True)
+        response.raw.read = partial(response.raw.read,
+                                    decode_content=True)
+        return uws.parse_job(response.raw.read)
+
+    def get_job_list(self, phases=None, after=None, last=None,
+                     short_description=True):
+        """
+        lists jobs that the caller can see in the current security context.
+        The list can be filtered on the server side by the phases of the jobs,
+        creation date time or
+        Note that by default jobs in 'ARCHIVED` phase are not returned.
+
+        Parameters
+        ----------
+        phases: list of str
+            Union of job phases to filter the results by.
+        after: datetime
+            Return only jobs created after this datetime
+        last: int
+            Return only the most recent number of jobs
+        short_description: flag - True or False
+            If True, the jobs in the list will contain only the information
+            corresponding to the TAP ShortJobDescription object (job ID, phase,
+            run ID, owner ID and creation ID) whereas if False, a separate GET
+            call to each job is performed for the complete job description.
+
+        Returns
+        -------
+        list of `~pyvo.io.vosi.endpoint.JobSummary`
+        """
+
+        params = {'PHASE': phases, 'LAST': last}
+
+        if after:
+            if isinstance(after, str):
+                after = _from_ivoa_format(after)
+            params['AFTER'] = after.strftime(IVOA_DATETIME_FORMAT)
+
+        response = self._session.get('{}/async'.format(self.baseurl),
+                                     params=params,
+                                     stream=True)
+        response.raw.read = partial(response.raw.read, decode_content=True)
+
+        jobs = uws.parse_job_list(response.raw.read)
+        if not short_description:
+            dj = []
+            for job in jobs:
+                dj.append(self.get_job(job.jobid))
+            return dj
+        else:
+            return list(jobs)
 
     def describe(self, width=None):
         """
@@ -319,7 +411,7 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
             print()
 
         capabilities = filter(
-            lambda x: not six.text_type(x.standardid).startswith(
+            lambda x: not str(x.standardid).startswith(
                 'ivo://ivoa.net/std/VOSI'),
             self.capabilities
         )
@@ -329,7 +421,7 @@ class TAPService(DALService, AvailabilityMixin, CapabilityMixin):
             print()
 
 
-class AsyncTAPJob(object):
+class AsyncTAPJob:
     """
     This class represents a UWS TAP Job.
     """
@@ -339,7 +431,7 @@ class AsyncTAPJob(object):
     @classmethod
     def create(
             cls, baseurl, query, language="ADQL", maxrec=None, uploads=None,
-            **keywords):
+            session=None, **keywords):
         """
         creates a async tap job on the server under `baseurl`
 
@@ -356,15 +448,17 @@ class AsyncTAPJob(object):
             the maximum records to return. defaults to the service default
         uploads : dict
             a mapping from table names to objects containing a votable
+        session : object
+           optional session to use for network requests
         """
         query = TAPQuery(
             baseurl, query, mode="async", language=language, maxrec=maxrec,
-            uploads=uploads, **keywords)
+            uploads=uploads, session=session, **keywords)
         response = query.submit()
-        job = cls(response.url)
+        job = cls(response.url, session=session)
         return job
 
-    def __init__(self, url):
+    def __init__(self, url, session=None):
         """
         initialize the job object with the given url and fetch remote values
 
@@ -374,6 +468,7 @@ class AsyncTAPJob(object):
             the job url
         """
         self._url = url
+        self._session = use_session(session)
         self._update()
 
     def __enter__(self):
@@ -397,13 +492,13 @@ class AsyncTAPJob(object):
         """
         try:
             if wait_for_statechange:
-                response = s.get(
+                response = self._session.get(
                     self.url, stream=True, timeout=timeout, params={
                         "WAIT": "-1"
                     }
                 )
             else:
-                response = s.get(self.url, stream=True, timeout=timeout)
+                response = self._session.get(self.url, stream=True, timeout=timeout)
             response.raise_for_status()
         except requests.RequestException as ex:
             raise DALServiceError.from_except(ex, self.url)
@@ -455,7 +550,7 @@ class AsyncTAPJob(object):
     @execution_duration.setter
     def execution_duration(self, value):
         try:
-            response = s.post(
+            response = self._session.post(
                 "{}/executionduration".format(self.url),
                 data={"EXECUTIONDURATION": str(value)})
             response.raise_for_status()
@@ -484,16 +579,13 @@ class AsyncTAPJob(object):
         value : datetime
             datetime after which the job results are deleted automatically
         """
-        try:
-            # is string? easier to ask for forgiveness
-            value = datetime.strptime(value, "%Y-%m-%dT%H:%M:%SZ")
-        except ValueError:
-            pass
+        if isinstance(value, str):
+            value = _from_ivoa_format(value)
 
         try:
-            response = s.post(
+            response = self._session.post(
                 "{}/destruction".format(self.url),
-                data={"DESTRUCTION": value.strftime("%Y-%m-%dT%H:%M:%SZ")})
+                data={"DESTRUCTION": value.strftime(IVOA_DATETIME_FORMAT)})
             response.raise_for_status()
         except requests.RequestException as ex:
             raise DALServiceError.from_except(ex, self.url)
@@ -530,7 +622,7 @@ class AsyncTAPJob(object):
     @query.setter
     def query(self, query):
         try:
-            response = s.post(
+            response = self._session.post(
                 '{}/parameters'.format(self.url),
                 data={"QUERY": query})
             response.raise_for_status()
@@ -551,7 +643,7 @@ class AsyncTAPJob(object):
         }
 
         try:
-            response = s.post(
+            response = self._session.post(
                 '{}/parameters'.format(self.url),
                 data={'UPLOAD': uploads.param()},
                 files=files
@@ -575,6 +667,10 @@ class AsyncTAPJob(object):
         The job result if exists
         """
         try:
+            for r in self._job.results:
+                if r.id_ == 'result':
+                    return r
+
             return self._job.results[0]
         except IndexError:
             return None
@@ -589,10 +685,10 @@ class AsyncTAPJob(object):
     @property
     def result_uri(self):
         """
-        the first result uri
+        the uri of the result
         """
         try:
-            return self.result_uris[0]
+            return self.result.href
         except IndexError:
             return None
 
@@ -606,7 +702,7 @@ class AsyncTAPJob(object):
         starts the job / change phase to RUN
         """
         try:
-            response = s.post(
+            response = self._session.post(
                 '{}/phase'.format(self.url), data={"PHASE": "RUN"})
             response.raise_for_status()
         except requests.RequestException as ex:
@@ -619,7 +715,7 @@ class AsyncTAPJob(object):
         aborts the job / change phase to ABORT
         """
         try:
-            response = s.post(
+            response = self._session.post(
                 '{}/phase'.format(self.url), data={"PHASE": "ABORT"})
             response.raise_for_status()
         except requests.RequestException as ex:
@@ -674,7 +770,7 @@ class AsyncTAPJob(object):
         deletes the job. this object will become invalid.
         """
         try:
-            response = s.post(self.url, data={"ACTION": "DELETE"})
+            response = self._session.post(self.url, data={"ACTION": "DELETE"})
             response.raise_for_status()
         except requests.RequestException as ex:
             raise DALServiceError.from_except(ex, self.url)
@@ -698,7 +794,7 @@ class AsyncTAPJob(object):
         returns the result votable if query is finished
         """
         try:
-            response = s.get(self.result_uri, stream=True)
+            response = self._session.get(self.result_uri, stream=True)
             response.raise_for_status()
         except requests.RequestException as ex:
             self._update()
@@ -708,7 +804,7 @@ class AsyncTAPJob(object):
 
         response.raw.read = partial(
             response.raw.read, decode_content=True)
-        return TAPResults(votableparse(response.raw.read), url=self.result_uri)
+        return TAPResults(votableparse(response.raw.read), url=self.result_uri, session=self._session)
 
 
 class TAPQuery(DALQuery):
@@ -733,7 +829,7 @@ class TAPQuery(DALQuery):
 
     def __init__(
             self, baseurl, query, mode="sync", language="ADQL", maxrec=None,
-            uploads=None, **keywords):
+            uploads=None, session=None, **keywords):
         """
         initialize the query object with the given parameters
 
@@ -751,10 +847,12 @@ class TAPQuery(DALQuery):
             the amount of records to fetch
         uploads : dict
             Files to upload. Uses table name as key and table content as value.
+        session : object
+           optional session to use for network requests
         """
         baseurl = baseurl.rstrip("?")
 
-        super(TAPQuery, self).__init__(baseurl, **keywords)
+        super().__init__(baseurl, session=session, **keywords)
 
         self._mode = mode if mode in ("sync", "async") else "sync"
         self._uploads = UploadList.fromdict(uploads or {})
@@ -791,7 +889,7 @@ class TAPQuery(DALQuery):
             raise DALServiceError(
                 "Cannot execute a non-synchronous query. Use submit instead")
 
-        return super(TAPQuery, self).execute_stream()
+        return super().execute_stream()
 
     def execute(self):
         """
@@ -807,7 +905,7 @@ class TAPQuery(DALQuery):
         DALFormatError
            for errors parsing the VOTable response
         """
-        return TAPResults(self.execute_votable(), url=self.queryurl)
+        return TAPResults(self.execute_votable(), url=self.queryurl, session=self._session)
 
     def submit(self):
         """
@@ -824,7 +922,7 @@ class TAPQuery(DALQuery):
             if upload.is_inline
         }
 
-        response = s.post(
+        response = self._session.post(
             url, data=self, stream=True, files=files)
         # requests doesn't decode the content by default
         response.raw.read = partial(response.raw.read, decode_content=True)
