@@ -3,9 +3,6 @@
 """
 Tests for pyvo.dal.datalink
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 from functools import partial
 
 import pytest
