@@ -2,9 +2,6 @@
 """
 This file contains xml element classes as defined in the VOResource standard.
 """
-from __future__ import (
-    absolute_import, division, print_function, unicode_literals)
-
 from functools import partial
 
 from astropy.utils.collections import HomogeneousList
@@ -53,13 +50,13 @@ def _convert_boolean(value, default=None):
 
 class UWSElement(Element):
     def __init__(self, config=None, pos=None, _name='', _ns='uws', **kwargs):
-        super(UWSElement, self).__init__(config, pos, _name, 'uws', **kwargs)
+        super().__init__(config, pos, _name, 'uws', **kwargs)
 
 
 class Reference(UWSElement):
     """standard xlink references"""
     def __init__(self, *args, **kwargs):
-        super(Reference, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self._type = kwargs.get('xlink:type')
         self._href = kwargs.get('xlink:href')
@@ -85,9 +82,8 @@ class Reference(UWSElement):
 
 class JobSummary(Element):
     def __init__(self, config=None, pos=None, _name='job', **kwargs):
-        super(JobSummary, self).__init__(config, pos, _name, **kwargs)
-
-        self._jobid = None
+        super().__init__(config, pos, _name, **kwargs)
+        self._jobid = kwargs.get('id')
         self._runid = None
         self._ownerid = None
         self._phase = None
@@ -100,10 +96,6 @@ class JobSummary(Element):
         self._parameters = Parameters()
         self._results = Results()
 
-    def parse(self, iterator, config):
-        super(JobSummary, self).parse(iterator, config)
-        return self
-
     @uwselement(name='jobId', plain=True)
     def jobid(self):
         """
@@ -223,7 +215,8 @@ class JobSummary(Element):
 
     @executionduration.formatter
     def executionduration(self):
-        return str(int(self._executionduration.value))
+        if self.executionduration:
+            return str(int(self._executionduration.value))
 
     @uwselement(plain=True)
     def destruction(self):
@@ -264,7 +257,26 @@ class JobSummary(Element):
         self._results = results
 
 
+class JobList(UWSElement, HomogeneousList):
+    def __init__(self, config=None, pos=None, _name='jobs', **kwargs):
+        HomogeneousList.__init__(self, JobSummary)
+        UWSElement.__init__(self, config, pos, _name, **kwargs)
+
+    @uwselement(name='jobref')
+    def jobs(self):
+        return self
+
+    @jobs.adder
+    def jobs(self, iterator, tag, data, config, pos):
+        job = JobSummary(config, pos, 'jobref', **data)
+        job.parse(iterator, config)
+        self.append(job)
+
+
 class Parameters(UWSElement, HomogeneousList):
+    """
+    Parameters element of a job
+    """
     def __init__(self, config=None, pos=None, _name='parameters', **kwargs):
         HomogeneousList.__init__(self, Parameter)
         UWSElement.__init__(self, config, pos, _name, **kwargs)
@@ -282,7 +294,7 @@ class Parameters(UWSElement, HomogeneousList):
 
 class Parameter(ContentMixin, UWSElement):
     def __init__(self, config=None, pos=None, _name='parameter', **kwargs):
-        super(Parameter, self).__init__(config, pos, _name, **kwargs)
+        super().__init__(config, pos, _name, **kwargs)
 
         self._byreference = _convert_boolean(kwargs.get('byReference'))
         self._id = kwargs.get('id')
@@ -328,7 +340,7 @@ class Results(UWSElement, HomogeneousList):
 class Result(Reference, UWSElement):
     """A reference to a UWS result."""
     def __init__(self, config=None, pos=None, _name='result', **kwargs):
-        super(Result, self).__init__(config, pos, _name, **kwargs)
+        super().__init__(config, pos, _name, **kwargs)
 
         self._id = kwargs.get('id')
         self._size = int(kwargs.get('size') or 0)
